@@ -3,10 +3,13 @@ import copy
 import json
 import os
 import re
-from typing import Any, Callable, Literal, TypeVar, Union, cast, Optional
+from typing import Any, Callable, Literal, Optional, TypeVar, Union, cast
 from urllib.parse import urljoin
 
 import requests
+from loguru import logger
+from pydantic import parse_obj_as
+
 from gable.openapi import (
     CheckComplianceDataAssetsPySparkRequest,
     CheckComplianceDataAssetsS3Request,
@@ -27,19 +30,18 @@ from gable.openapi import (
     ErrorResponseDeprecated,
     GetNpmCredentialsResponse,
     GetPipCredentialsResponse,
+    GetScaRunStatusResponse,
     IngestDataAssetResponse,
     PostContractRequest,
     PostContractResponse,
+    PostScaStartRunRequest,
+    PostScaStartRunResponse,
     RegisterDataAssetPySparkRequest,
     RegisterDataAssetS3Request,
     RegisterDataAssetsRequest,
     RegisterDataAssetsResponse,
     ResponseType,
-    PostScaStartRunRequest,
-    PostScaStartRunResponse
 )
-from loguru import logger
-from pydantic import parse_obj_as
 
 T = TypeVar("T")
 
@@ -316,12 +318,26 @@ class GableAPIClient:
         request: PostScaStartRunRequest,
     ) -> tuple[Union[PostScaStartRunResponse, ErrorResponse], bool, int]:
         """Start a new SCA run with the given parameters."""
-        response, success, status_code = self._post("v0/sca/start-run", json=json.loads(request.json(by_alias=True, exclude_none=True)))
+        response, success, status_code = self._post(
+            "v0/sca/start-run",
+            json=json.loads(request.json(by_alias=True, exclude_none=True)),
+        )
         if success:
             return PostScaStartRunResponse.parse_obj(response), success, status_code
         else:
             return ErrorResponse.parse_obj(response), success, status_code
 
+    def get_sca_run_status(
+        self,
+        job_id: str,
+    ) -> tuple[Union[GetScaRunStatusResponse, ErrorResponse], bool, int]:
+        """Get Status of SCA job with job id."""
+        response, success, status_code = self._get(f"v0/sca/status/{job_id}")
+        if success:
+            return GetScaRunStatusResponse.parse_obj(response), success, status_code
+        else:
+            return ErrorResponse.parse_obj(response), success, status_code
+
     def get_data_asset(
         self, data_asset_resource_name: str
     ) -> Union[DataAsset, ErrorResponse]:
@@ -442,6 +458,16 @@ class GableAPIClient:
                 result_darns.append(full_darn)
         return result_darns
 
+    def get_cross_service_components(
+        self,
+    ) -> dict:
+        response, _, _ = self._get("v0/cross-service-components")
+        if not isinstance(response, dict):
+            raise Exception(
+                f"Unexpected response received from /cross-service-components: {response}"
+            )
+        return response
+
 
 def del_none(d):
     """
@@ -482,6 +508,6 @@ def parse_check_data_asset_response(response) -> CheckDataAssetResponse:
     response_type = response["responseType"]
     if response_type in response_mapping:
         return CheckDataAssetResponse(
-            __root__=parse_obj_as(response_mapping[response_type], response)
+            root=parse_obj_as(response_mapping[response_type], response)
         )
     raise ValueError(f"Unknown response type: {response_type} in response: {response}")
