@@ -3,10 +3,11 @@ import os
 
 import click
 from click.core import Context as ClickContext
+from loguru import logger
+
 from gable.api.client import GableAPIClient
 from gable.cli.helpers.repo_interactions import get_pr_link
 from gable.cli.options import global_options
-from loguru import logger
 
 
 @click.group(hidden=True)
@@ -45,20 +46,3 @@ def env(_ctx: ClickContext):
     logger.info(
         "Note: these can be overridden by passing command line arguments to gable."
     )
-
-
-@debug.command()
-@global_options()
-@click.pass_context
-def pyping(ctx: ClickContext):
-    """Pings the Gable API (python server) to check for connectivity"""
-    client: GableAPIClient = ctx.obj.client
-    try:
-        response, success, status_code = client.get_pyping()
-    except Exception as e:
-        raise click.ClickException(
-            f"Unable to ping Gable API at {client.endpoint}: {str(e)}"
-        )
-    if not success:
-        raise click.ClickException(f"Unable to ping Gable API at {client.endpoint}")
-    logger.info(f"Successfully pinged Gable API at {client.endpoint}")
