@@ -97,7 +97,7 @@ def get_schemas_from_files(
         skip_profiling=True,
     )
 
-    return [s3_data.schema]
+    return [s3_data.schema]  # type: ignore
 
 
 def compare_schemas(
@@ -109,7 +109,9 @@ def compare_schemas(
 ):
     """Compare two sets of schemas and log the differences."""
     for schema_h, schema_t in zip(schema1, schema2):
-        diff = deepdiff.DeepDiff(schema_h, schema_t, ignore_order=True)
+        diff = deepdiff.DeepDiff(
+            schema_h, schema_t, ignore_order=True, threshold_to_diff_deeper=0
+        )
         if diff:
             formatted_results = format_deepdiff_output(diff)
             logger.info(
