@@ -16,14 +16,7 @@ from gable.api.client import GableAPIClient
 from gable.cli.helpers.auth import set_npm_config_credentials
 from gable.cli.helpers.logging import get_winston_log_level
 from gable.cli.local import get_local_sca_path, get_local_sca_prime
-from gable.openapi import CreateTelemetryRequest, TelemetryType
-
-BASE_NPX_CMD = [
-    "npx",
-    "-y",
-    "-q",
-    "@gable-eng/sca@<1.0.0",
-]
+from gable.openapi import CreateTelemetryRequest, SourceType, TelemetryType
 
 # Used for gable cli command in docker container environments
 DOCKER_NODE_CMD = [
@@ -31,10 +24,19 @@ DOCKER_NODE_CMD = [
     "/app/npm/dist/index.cjs",
 ]
 
+# Required feature flag value when running in isolated mode
+REQUIRED_ISOLATION_FEATURE_FLAG = "GDoBcuPkip0K9RZTTWFJwZ8YyMXgeb"
+
 
 def prepare_npm_environment(client: GableAPIClient) -> None:
     if os.getenv("GABLE_CLI_ISOLATION", "false").lower() == "true":
-        logger.debug("GABLE_CLI_ISOLATION is true, skipping NPM authentication.")
+        logger.debug("Running Gable cli in isolation")
+        # Require a feature flag when running in isolated mode
+        feature_flag = os.getenv("GABLE_CLI_FEATURE_FLAG", "")
+        if feature_flag != REQUIRED_ISOLATION_FEATURE_FLAG:
+            raise click.ClickException(
+                f"Limited permission to run Gable CLI. Please contact Gable Support for assistance."
+            )
         return
     # Verify node is installed
     check_node_installed()
@@ -163,6 +165,7 @@ def run_sca_python(
 
 def run_sca_typescript(
     library: Optional[str],
+    rules_file: Optional[str],
     node_modules_include: Optional[str],
     project_root: str,
     emitter_file_path: Optional[str],
@@ -174,9 +177,14 @@ def run_sca_typescript(
     client: GableAPIClient,
 ) -> tuple[str, dict[str, dict[str, Any]]]:
     try:
+        options = []
+
         if library is not None:
             options = ["--library", library]
-        else:
+        # Rules file takes precedence over --emitter-* args
+        elif rules_file is not None:
+            options = ["--rules-file", os.path.abspath(rules_file)]
+        elif emitter_function is not None:
             options = [
                 # TODO: switch this to --emitter-location once the new NPM package is released
                 # and some time has passed
@@ -201,7 +209,9 @@ def run_sca_typescript(
             client.endpoint,
             ["typescript", project_root] + options,
         )
-        sca_prime_results_future = start_sca_prime(client, project_root, [])
+        sca_prime_results_future = start_sca_prime(
+            client, project_root, [], [], SourceType.typescript
+        )
         result_proc = subprocess.Popen(
             cmd,
             stdout=subprocess.PIPE,
@@ -230,11 +240,10 @@ def run_sca_typescript(
         logger.debug(result_proc_stdout)
 
         # Run sca-prime
-        sca_prime_results, _ = get_sca_prime_results(
-            sca_prime_results_future, client, project_root, True
-        )
+        # NOTE: We don't use the results, we just run SCA prime to collect metrics
+        get_sca_prime_results(sca_prime_results_future, client, project_root, True)
         # The sca CLI prints the results to stdout,and everything else to trace/warn/debug/error
-        return result_proc_stdout, sca_prime_results
+        return result_proc_stdout, {}
     except Exception as e:
         logger.opt(exception=e).debug("Error running Gable SCA")
         raise click.ClickException(
@@ -257,6 +266,12 @@ def get_sca_cmd(gable_api_endpoint: Union[str, None], args: list[str]) -> list[s
     return cmd
 
 
+def get_base_sca_package() -> str:
+    """Get the SCA package version to use, either from environment variable or default"""
+    version = os.environ.get("GABLE_SCA_VERSION", "<1.0.0")
+    return f"@gable-eng/sca@{version}"
+
+
 def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
     """Based on the endpoint and GABLE_LOCAL environment variable, decide if we should use the local package
     Returns: list[str] - The base command to run sca, either using npx + @gable-eng/sca or node + local path
@@ -273,7 +288,7 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
         try:
             local_sca_path = get_local_sca_path()
             product_dir = os.path.dirname(
-                os.path.dirname(os.path.dirname(os.path.dirname(local_sca_path)))
+                os.path.dirname(os.path.dirname(os.path.dirname(local_sca_path)))  # type: ignore
             )
             tsx_path = os.path.join(
                 product_dir, "node_modules", "tsx", "dist", "cli.mjs"
@@ -288,7 +303,7 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
             )
             local_sca_path = os.environ.get("GABLE_LOCAL_SCA_PATH")
             product_dir = os.path.dirname(
-                os.path.dirname(os.path.dirname(os.path.dirname(local_sca_path)))
+                os.path.dirname(os.path.dirname(os.path.dirname(local_sca_path)))  # type: ignore
             )
             tsx_path = os.path.join(
                 product_dir, "node_modules", "tsx", "dist", "cli.mjs"
@@ -299,7 +314,15 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
                     local_sca_path,
                 ]
 
-    return BASE_NPX_CMD
+    # Construct npx command with the base SCA package
+    npx_cmd = [
+        "npx",
+        "-y",
+        "-q",
+        get_base_sca_package(),
+    ]
+
+    return npx_cmd
 
 
 def should_use_docker_node_cmd() -> bool:
@@ -334,8 +357,11 @@ def start_sca_prime(
     client: GableAPIClient,
     project_root: str,
     annotations: List[str],
+    exclude_patterns: List[str],
+    lang: SourceType,
     sca_debug: bool = False,
     semgrep_bin_path: Optional[str] = None,
+    rules_file: Optional[str] = None,
 ) -> Union[tuple[subprocess.Popen, str], None]:
     # return process and tempdir if no error, else None
     if os.environ.get("ENABLE_SCA_PRIME", "true").lower() != "true":
@@ -361,12 +387,19 @@ def start_sca_prime(
             "fs",
             "--output-path",
             temp_dir,
+            "--include-langs",
+            lang.value,
         ]
         if annotations:
             command += ["--annotations"]
             command += annotations
+        if rules_file:
+            command += ["--rules-file", rules_file]
         if sca_debug:
             command += ["--debug"]
+        if exclude_patterns:
+            command += ["--exclude-pattern"]
+            command += exclude_patterns
 
         logger.debug("Running sca-prime command: {}", " ".join(command))
         process = subprocess.Popen(
@@ -429,9 +462,9 @@ def get_sca_prime_results(
     client: GableAPIClient,
     project_root: str,
     post_metrics=True,
-) -> tuple[dict[str, dict[str, Any]], dict]:
+) -> list[dict[str, Any]]:
     if sca_prime_process_data is None:
-        return {}, {}
+        return []
     sca_prime_process, temp_dir = sca_prime_process_data
     try:
         sca_prime_process.wait()
@@ -464,31 +497,18 @@ def get_sca_prime_results(
 
         if not os.path.exists(findings_file):
             logger.debug("SCA prime generated findings file not found")
-            return {}, {}
+            return []
 
-        with open(findings_file, "r") as f:
-            all_findings = json.load(f)["findings"]
+        from gable.cli.commands.asset_plugins.sca_prime import ScaPrimePlugin
 
-            location_results = {
-                f'{finding["recap"]["name"]}': (
-                    finding["recap"],
-                    finding["source_location"],
-                )
-                for finding in all_findings
-            }
+        findings = ScaPrimePlugin.extract_from_json_file(findings_file)
 
-            recap_results = [finding["recap"] for finding in all_findings]
-            dict_result = {
-                f'{recap_struct["name"]}': recap_struct
-                for recap_struct in recap_results
-            }
-
-            logger.debug(f"Results from sca-prime: {dict_result}")
-            return dict_result, location_results
+        logger.debug(f"Results from sca-prime: {len(findings)} findings")
+        return findings
 
     except Exception as e:
         logger.opt(exception=e).debug(f"Error running SCA Prime in shadow mode {e}", e)
-        return {}, {}
+        return []
     finally:
         shutil.rmtree(temp_dir)
 
