@@ -3,7 +3,7 @@
 import json
 import os
 import time
-from typing import Tuple
+from typing import Literal, Tuple, Union
 
 import click
 import requests
@@ -12,25 +12,30 @@ from loguru import logger
 from gable.api.client import GableAPIClient
 from gable.cli.helpers.npm import get_installed_package_dir
 from gable.cli.helpers.repo_interactions import get_git_repo_info, get_pr_link
+from gable.common_types import LineageDataFile
 from gable.openapi import (
     Action1,
+    CrossServiceDataStore,
+    CrossServiceEdge,
     ErrorResponse,
     OutputFormat,
     PostScaStartRunRequest,
     S3PresignedUrl,
     StaticAnalysisCodeMetadata,
-    StaticAnalysisPathsUploadRequest,
     StaticAnalysisToolConfig,
     StaticAnalysisToolMetadata,
+    Type,
 )
 
 
 def start_sca_run(
     client: GableAPIClient,
     project_root: str,
-    action: str,
+    action: Literal["register", "check", "upload"],
     output: str | None,
     include_unchanged_assets: bool | None,
+    external_component_id: str | None,
+    upload_type: Type | None,
 ) -> Tuple[str, S3PresignedUrl]:
     """Call the SCA start run API to get the S3 presigned URL to upload the SCA results
 
@@ -57,10 +62,9 @@ def start_sca_run(
         }
 
     package_name, package_version = get_sca_package_info()
-    action_name = Action1.check if action == "check" else Action1.register
     include = True if include_unchanged_assets else False
     output_f = None
-    if action_name == "check":
+    if action == "check":
         if output == "markdown":
             output_f = OutputFormat.markdown
         elif output == "text":
@@ -75,6 +79,7 @@ def start_sca_run(
                 repo_branch=git_info["gitBranch"],
                 repo_commit=git_info["gitHash"],
                 project_root=project_root,
+                external_component_id=external_component_id,
             ),
             sca_info=StaticAnalysisToolMetadata(
                 name=package_name,
@@ -84,10 +89,11 @@ def start_sca_run(
                     egress_signatures=[],
                 ),
             ),
-            action=action_name,
+            action=Action1(action),
             pr_link=get_pr_link(),
             output_format=output_f,
             include_unchanged_assets=include,
+            type=upload_type,
         )
     )
 
@@ -179,36 +185,56 @@ def poll_sca_job_status(
 
 
 def upload_sca_results(
-    run_id: str, presigned_url: S3PresignedUrl, results_dir: str
+    run_id: str,
+    presigned_url: S3PresignedUrl,
+    lineage_data_file: Union[CrossServiceDataStore, CrossServiceEdge, LineageDataFile],
 ) -> None:
     """Upload SCA results to S3 using the presigned URL.
 
     Args:
+        run_id: The ID of the run
         presigned_url: The S3 presigned URL to upload to
-        results_dir: The directory containing the SCA results file
+        lineage_data_file: The lineage object to serialize and upload
     """
-    try:
-        logger.debug(
-            f'Uploading results from {os.path.join(results_dir, "results.json")}'
+
+    if isinstance(lineage_data_file, LineageDataFile):
+        upload_request = LineageDataFile(
+            run_id=run_id,
+            paths=lineage_data_file.paths,
+            external_component_id=lineage_data_file.external_component_id,
+        )
+    elif isinstance(lineage_data_file, CrossServiceDataStore):
+        upload_request = CrossServiceDataStore(
+            external_component_id=lineage_data_file.external_component_id,
+            type=lineage_data_file.type,
+            external_table_id=lineage_data_file.external_table_id,
+            schema=lineage_data_file.schema_,
+            table_metadata=lineage_data_file.table_metadata,
+        )
+    elif isinstance(lineage_data_file, CrossServiceEdge):
+        upload_request = CrossServiceEdge(
+            source_component_id=lineage_data_file.source_component_id,
+            destination_component_id=lineage_data_file.destination_component_id,
+            external_edge_id=lineage_data_file.external_edge_id,
+            type=lineage_data_file.type,
+            field_mappings=lineage_data_file.field_mappings,
+            source=lineage_data_file.source,
+            destination=lineage_data_file.destination,
+        )
+    else:
+        raise ValueError(
+            f"Unsupported lineage_data_file type: {type(lineage_data_file)}"
         )
-        # Read the SCA results file - hardcoded to results.json right now
-        with open(os.path.join(results_dir, "results.json"), "rb") as f:
-            file_content = f.read()
 
-        results_json = json.loads(file_content)
-        results_json["run_id"] = run_id
-        results = StaticAnalysisPathsUploadRequest.parse_obj(results_json)
-
-        # Create form data
+    try:
         files = {
             "file": (
                 "results.json",
-                results.json(by_alias=True, exclude_none=True).encode("utf-8"),
+                upload_request.json(by_alias=True, exclude_none=True).encode("utf-8"),
                 "application/octet-stream",
             )
         }
         data = presigned_url.fields
-        # Upload to S3 with the complete form data as the body
         response = requests.post(presigned_url.url, files=files, data=data)
         response.raise_for_status()
         logger.debug("Successfully uploaded SCA results to S3")
