@@ -118,10 +118,13 @@ def logging_options(func, global_option_group: OptionGroup):
         callback=configure_trace_logger,
     )
     @functools.wraps(func)
-    def wrapper(*args, **kwargs):
+    @click.pass_context
+    def wrapper(ctx: click.Context, *args, **kwargs):
         # Check if debug logging is enabled
         debug_logging_enabled = "debug" in kwargs and kwargs["debug"]
         trace_logging_enabled = "trace" in kwargs and kwargs["trace"]
+        ctx.obj.debug = debug_logging_enabled or getattr(ctx.obj, "debug", False)
+        ctx.obj.trace = trace_logging_enabled or getattr(ctx.obj, "trace", False)
         # We need to remove the debug/trace flags from the kwargs before passing them to the subcommand functions
         # because they don't expect it
         if "debug" in kwargs:
@@ -451,6 +454,11 @@ def typescript_project_options(
             help="This should indicate the library emitting the events you want detected as data assets.",
             type=click.Choice(ALL_TYPESCRIPT_LIBRARY_VALUES),
         )
+        @optgroup.option(
+            "--rules-file",
+            help="File containing match rules for egress points. Can be used in conjunction with --library, but takes precedence over --emitter-* args.",
+            type=str,
+        )
         @optgroup.option(
             "--node-modules-include",
             help="Comma delimited list of filenames or patterns of node modules to include in the analysis.",
