@@ -1,4 +1,6 @@
-from .openapi import SourceType
+from typing import Optional
+
+from .openapi import SourceType, StaticAnalysisPathsUploadRequest
 
 ALL_SOURCE_TYPES = list(SourceType)
 
@@ -18,3 +20,9 @@ STATIC_CODE_ANALYSIS_SOURCE_TYPES = [
 ]
 
 SCHEMA_SOURCE_TYPES = DATABASE_SOURCE_TYPES + FILE_SOURCE_TYPES
+
+
+class LineageDataFile(StaticAnalysisPathsUploadRequest):
+    run_id: Optional[str] = (
+        None  # make optional for upload direct file, we will add this before upload
+    )
