@@ -64,12 +64,10 @@ class TrinoDataType(str, Enum):
         data_type = data_type.upper()
         args = None
         # Check for args like DECIMAL(10, 2) or ARRAY(VARCHAR)
-        match = re.match(r"([A-Z\s]+)(\(.+\))", data_type)
+        match = re.match(r"([A-Z\s]+)\((.+)\)", data_type)
         if match:
             data_type = match.group(1)
-            args = [
-                try_parse_int(a.strip()) for a in match.group(2).strip("()").split(",")
-            ]
+            args = [try_parse_int(a.strip()) for a in match.group(2).split(",")]
         # "TIME WITH TIME ZONE " -> "TIME_WITH_TIME_ZONE"
         data_type = re.sub(r"\s+", "_", data_type.strip())
         if args:
